pub struct App { /* private fields */ }Implementations
Sourceimpl App
impl App
pub fn new(args: &CliArgs, ui: Box<dyn AppUi>, repo_dir: &str) -> App
pub fn get_protected_branches(&self) -> HashSet<String>
pub fn is_working_tree_clean(&self) -> bool
Sourcepub fn find_default_branch_from_git(&self) -> Result<String, AppError>
pub fn find_default_branch_from_git(&self) -> Result<String, AppError>
Ask git the name of the default branch, and store the result in git config. If we can’t find it using git, fallback to asking the user.
Sourcepub fn find_default_branch_from_user(&self) -> Result<String, AppError>
pub fn find_default_branch_from_user(&self) -> Result<String, AppError>
Ask the user the name of the default branch, and store the result in git config
Sourcepub fn get_default_branch(&self) -> Result<Option<String>, AppError>
pub fn get_default_branch(&self) -> Result<Option<String>, AppError>
Return the default branch stored in git config, if any
pub fn fetch_changes(&self) -> Result<(), AppError>
pub fn update_tracking_branches(&self) -> Result<(), AppError>
pub fn remove_merged_branches(&self) -> Result<(), AppError>
pub fn do_delete_identical_branches( &self, sha1: &str, branch_set: &HashSet<String>, ) -> Result<(), AppError>
pub fn delete_identical_branches(&self) -> Result<(), AppError>
pub fn safe_delete_branch(&self, branch: &str) -> Result<(), AppError>
pub fn add_default_branch_to_protected_branches( &mut self, ) -> Result<(), AppError>
pub fn run(&mut self) -> Result<(), AppError>